/* Copyright (c) 1998, MpegTV LLC */
#ifndef _voh_x_api_h
#define _voh_x_api_h
#ifndef lint
static const char rcsid_voh_x_api_h[] = "$Header: /net/hopkins/home/tristan/mpeg/dec/RCS/voh_x_api.h,v 1.104 1999/05/01 08:13:18 tristan Exp tristan $";
#endif

/*
 * Disclaimer of Warranty
 *
 * These software programs are available to the user without any license fee or
 * royalty on an "as is" basis.  Copyright-holder disclaims
 * any and all warranties, whether express, implied, or statuary, including any
 * implied warranties or merchantability or of fitness for a particular
 * purpose.  In no event shall the copyright-holder be liable for any
 * incidental, punitive, or consequential damages of any kind whatsoever
 * arising from the use of these programs.
 *
 * This disclaimer of warranty extends to the user of these programs and user's
 * customers, employees, agents, transferees, successors, and assigns.
 *
 */

/* VOH = Video Output Handler */

#include "mtvp/misc.h"

#include <X11/Xlib.h>

/*--------------------------------------------------------------------------+
| Configuration																|
+--------------------------------------------------------------------------*/

/*--------------------------------------------------------------------------+
| Macros																	|
+--------------------------------------------------------------------------*/

/* use root window */
#define MTVP_VOH_X_WINDOW_ROOT	((MTVP_VOH_WINDOW)(-1))

/* create new window (default) */
#define MTVP_VOH_X_WINDOW_NONE	((MTVP_VOH_WINDOW)0)

/*--------------------------------------------------------------------------+
| Data types																|
+--------------------------------------------------------------------------*/
struct mtvp_voh_x_window_position {
	int		x;	/* window horizontal position */
	int		y;	/* window vertical position */
};

/* Specific VOH_FEEDBACK data from the X Video Output Handler */
typedef struct {

	/* type of X-specific message */
	enum {
		MTVP_VOH_X_FEEDBACK_TYPE_NO_SHARED_MEMORY = 0,	/* no associated data */
		MTVP_VOH_X_FEEDBACK_TYPE_EVENT = 1,				/* associated data is XEvent */
		MTVP_VOH_X_FEEDBACK_TYPE_PRIVATE_CLUT = 2,		/* no associated data */
		MTVP_VOH_X_FEEDBACK_TYPE_WINDOW_POSITION = 3,	/* associated data is window_position */
	} type;	

	/* associated data */
	union {
		XEvent	event;	
		struct mtvp_voh_x_window_position window_position;
	} data;
	
} MTVP_VOH_X_FEEDBACK_DATA;

/* Specific MTVP_COMMAND_VOH_X_FEEDBACK data from the X Video Output Handler */
typedef struct {
	int handler_id;		/* VOH_X_HANDLER */
	MTVP_VOH_X_FEEDBACK_DATA data_x;
} MTVP_VOH_X_FEEDBACK;


/* type of video layout */
typedef enum mtvp_voh_x_video_layout {
	MTVP_VOH_X_VIDEO_LAYOUT_CENTERED = 0,
	MTVP_VOH_X_VIDEO_LAYOUT_FILL_WINDOW = 1,
	MTVP_VOH_X_VIDEO_LAYOUT_TOP_LEFT = 2
} MTVP_VOH_X_VIDEO_LAYOUT;

struct mtvp_voh_x_scale {
	double  horizontal;
	double  vertical;
};

/* Specific VOH_CNTL for the X Video Output Handler */
typedef struct {

	/* this MTVP_VOH_X_CNTL structure must start with handler_id (int32) */
	int32	handler_id;

	/* type of X-specific message */
	enum {
		MTVP_VOH_X_CNTL_TYPE_SET_EVENT_MASK = 0,
		MTVP_VOH_X_CNTL_TYPE_USE_PRIVATE_CLUT = 1,
		MTVP_VOH_X_CNTL_TYPE_RAISE_WINDOW = 2,
		MTVP_VOH_X_CNTL_TYPE_SET_VIDEO_LAYOUT = 3,
		MTVP_VOH_X_CNTL_TYPE_SET_ICON_NAME = 4,
		MTVP_VOH_X_CNTL_TYPE_SET_WINDOW_NAME = 5,
		MTVP_VOH_X_CNTL_TYPE_SET_WINDOW_POSITION = 6,
		MTVP_VOH_X_CNTL_TYPE_SET_SCALE = 7,
	} type;	

	/* associated data */
	union {
		long				event_mask;
		Bool				use_private_clut;	
		MTVP_VOH_X_VIDEO_LAYOUT	video_layout;	
		char				icon_name[256];	
		char				window_name[256];	
		struct mtvp_voh_x_scale 		scale;
		struct mtvp_voh_x_window_position window_position;
	} data;
	
} MTVP_VOH_X_CNTL;


#endif /* _voh_x_api_h */
